==> numba_dpex-0.21.2-4-cp310-cp310-win_amd64.whl: numba_dpex/tests/dpjit_tests/dpnp/test_dpnp_zeros.py <==
# SPDX-FileCopyrightText: 2020 - 2023 Intel Corporation
#
# SPDX-License-Identifier: Apache-2.0

"""Tests for dpnp ndarray constructors."""

import dpctl
import dpnp
import pytest
from numba import errors

from numba_dpex import dpjit

shapes = [11, (3, 7)]
dtypes = [dpnp.int32, dpnp.int64, dpnp.float32, dpnp.float64]
usm_types = ["device", "shared", "host"]


@pytest.mark.parametrize("shape", shapes)
def test_dpnp_zeros_default(shape):
    """Test dpnp.zeros() with default parameters inside dpjit."""

    @dpjit
    def func(shape):
        c = dpnp.zeros(shape)
        return c

    try:
        c = func(shape)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert not c.asnumpy().any()

    dummy = dpnp.zeros(shape)

    assert c.dtype == dummy.dtype
    assert c.usm_type == dummy.usm_type
    assert c.sycl_device == dummy.sycl_device
    if c.sycl_queue != dummy.sycl_queue:
        pytest.xfail(
            "Returned queue does not have the same queue as in the dummy array."
        )
    assert c.sycl_queue == dpctl._sycl_queue_manager.get_device_cached_queue(
        dummy.sycl_device
    )


@pytest.mark.parametrize("shape", shapes)
@pytest.mark.parametrize("dtype", dtypes)
@pytest.mark.parametrize("usm_type", usm_types)
def test_dpnp_zeros_from_device(shape, dtype, usm_type):
    """ "Use device only in dpnp.zeros() inside dpjit."""
    device = dpctl.SyclDevice().filter_string

    @dpjit
    def func(shape):
        c = dpnp.zeros(shape, dtype=dtype, usm_type=usm_type, device=device)
        return c

    try:
        c = func(shape)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert c.dtype == dtype
    assert c.usm_type == usm_type
    assert c.sycl_device.filter_string == device
    if c.sycl_queue != dpctl._sycl_queue_manager.get_device_cached_queue(
        device
    ):
        pytest.xfail(
            "Returned queue does not have the same queue as cached against the device."
        )
    assert not c.asnumpy().any()


@pytest.mark.parametrize("shape", shapes)
@pytest.mark.parametrize("dtype", dtypes)
@pytest.mark.parametrize("usm_type", usm_types)
def test_dpnp_zeros_from_queue(shape, dtype, usm_type):
    """ "Use queue only in dpnp.zeros() inside dpjit."""

    @dpjit
    def func(shape, queue):
        c = dpnp.zeros(shape, dtype=dtype, usm_type=usm_type, sycl_queue=queue)
        return c

    try:
        queue = dpctl.SyclQueue()
        c = func(shape, queue)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert c.dtype == dtype
    assert c.usm_type == usm_type
    assert c.sycl_device == queue.sycl_device
    assert not c.asnumpy().any()

    if c.sycl_queue != queue:
        pytest.xfail(
            "Returned queue does not have the same queue as the one passed to the dpnp function."
        )


def test_dpnp_zeros_exceptions():
    """Test if exception is raised when both queue and device are specified."""
    device = dpctl.SyclDevice().filter_string

    @dpjit
    def func(shape, queue):
        c = dpnp.zeros(shape, sycl_queue=queue, device=device)
        return c

    try:
        queue = dpctl.SyclQueue()
        func(10, queue)
    except Exception as e:
        assert isinstance(e, errors.TypingError)
        assert "`device` and `sycl_queue` are exclusive keywords" in str(e)

==> numba_dpex-0.21.4-2-cp310-cp310-win_amd64.whl: numba_dpex/tests/dpjit_tests/dpnp/test_dpnp_zeros.py <==
# SPDX-FileCopyrightText: 2020 - 2023 Intel Corporation
#
# SPDX-License-Identifier: Apache-2.0

"""Tests for dpnp ndarray constructors."""

import dpctl
import dpnp
import pytest
from numba import errors

from numba_dpex import dpjit
from numba_dpex.tests._helper import get_all_dtypes

shapes = [11, (3, 7)]
dtypes = get_all_dtypes(
    no_bool=True, no_float16=True, no_none=True, no_complex=True
)
usm_types = ["device", "shared", "host"]


@pytest.mark.parametrize("shape", shapes)
def test_dpnp_zeros_default(shape):
    """Test dpnp.zeros() with default parameters inside dpjit."""

    @dpjit
    def func(shape):
        c = dpnp.zeros(shape, dtype=dpnp.float32)
        return c

    try:
        c = func(shape)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert not c.asnumpy().any()

    dummy = dpnp.zeros(shape, dtype=dpnp.float32)

    assert c.dtype == dummy.dtype
    assert c.usm_type == dummy.usm_type
    assert c.sycl_device == dummy.sycl_device
    if c.sycl_queue != dummy.sycl_queue:
        pytest.xfail(
            "Returned queue does not have the same queue as in the dummy array."
        )
    assert c.sycl_queue == dpctl._sycl_queue_manager.get_device_cached_queue(
        dummy.sycl_device
    )


@pytest.mark.parametrize("shape", shapes)
@pytest.mark.parametrize("dtype", dtypes)
@pytest.mark.parametrize("usm_type", usm_types)
def test_dpnp_zeros_from_device(shape, dtype, usm_type):
    """ "Use device only in dpnp.zeros() inside dpjit."""
    device = dpctl.SyclDevice().filter_string

    @dpjit
    def func(shape):
        c = dpnp.zeros(shape, dtype=dtype, usm_type=usm_type, device=device)
        return c

    try:
        c = func(shape)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert c.dtype == dtype
    assert c.usm_type == usm_type
    assert c.sycl_device.filter_string == device
    if c.sycl_queue != dpctl._sycl_queue_manager.get_device_cached_queue(
        device
    ):
        pytest.xfail(
            "Returned queue does not have the same queue as cached against the device."
        )
    assert not c.asnumpy().any()


@pytest.mark.parametrize("shape", shapes)
@pytest.mark.parametrize("dtype", dtypes)
@pytest.mark.parametrize("usm_type", usm_types)
def test_dpnp_zeros_from_queue(shape, dtype, usm_type):
    """ "Use queue only in dpnp.zeros() inside dpjit."""

    @dpjit
    def func(shape, queue):
        c = dpnp.zeros(shape, dtype=dtype, usm_type=usm_type, sycl_queue=queue)
        return c

    try:
        queue = dpctl.SyclQueue()
        c = func(shape, queue)
    except Exception:
        pytest.fail("Calling dpnp.zeros() inside dpjit failed.")

    if len(c.shape) == 1:
        assert c.shape[0] == shape
    else:
        assert c.shape == shape

    assert c.dtype == dtype
    assert c.usm_type == usm_type
    assert c.sycl_device == queue.sycl_device
    assert not c.asnumpy().any()

    if c.sycl_queue != queue:
        pytest.xfail(
            "Returned queue does not have the same queue as the one passed to the dpnp function."
        )


def test_dpnp_zeros_exceptions():
    """Test if exception is raised when both queue and device are specified."""
    device = dpctl.SyclDevice().filter_string

    @dpjit
    def func(shape, queue):
        c = dpnp.zeros(shape, sycl_queue=queue, device=device)
        return c

    try:
        queue = dpctl.SyclQueue()
        func(10, queue)
    except Exception as e:
        assert isinstance(e, errors.TypingError)
        assert "`device` and `sycl_queue` are exclusive keywords" in str(e)
